@@ -1,4 +1,9 @@
+from decimal import Decimal
 from enum import Enum
+from fractions import Fraction
+from typing import Union
+
+from vapoursynth import PresetFormat, VideoFormat, VideoNode
 
 
 class ChromaSubsampleScanning(Enum):
@@ -24,3 +29,8 @@ class InterlacedScanPostProcessor(Enum):
     BLEND_VERTICALLY = 'BLEND_VERTICALLY'
     """Blends the entire contents vertically to remove comb lines. You
     effectively lose close to half of the vertical detail as a side effect."""
+
+
+Factor = Union[int, float, Decimal, Fraction]
+
+FormatSpecifier = Union[PresetFormat, VideoFormat, VideoNode, int]
